@@ -1,5 +1,5 @@
 package DB_File::Utils::Command::keys;
-$DB_File::Utils::Command::keys::VERSION = '0.002';
+$DB_File::Utils::Command::keys::VERSION = '0.003';
 use v5.20;
 use DB_File::Utils -command;
 use strict;
@@ -32,16 +32,15 @@ sub execute {
 	$opt = { %{$self->app->global_options}, %$opt};
 
 	foreach my $file (@$args) {
-		_dump($file);
+		_dump($self, $file, $opt);
 	}
 }
 
 sub _dump {
-	my $filename = shift;
-	my %hash;
-	tie %hash,  'DB_File', $filename, O_RDWR, '0666', $DB_BTREE;
-	say while (($_) = each %hash);
-	untie %hash;
+	my ($self, $filename, $opt) = @_;
+	my $hash = $self->app->do_tie( $filename, $opt);
+	say while (($_) = each %$hash);
+	untie $hash;
 }
 
 1;
\ No newline at end of file
